@@ -40,14 +40,28 @@ class CloudRegion(Enum):
     GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
     GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
     GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
-    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
-    AZURE_EUROPE_NORTH = "AZURE_EUROPE_NORTH"
-    AZURE_US_WEST2 = "AZURE_US_WEST2"
-    AZURE_US_EAST = "AZURE_US_EAST"
-    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
+    AZURE_ASIA_EAST = "AZURE_ASIA_EAST"
+    AZURE_ASIA_SOUTHEAST = "AZURE_ASIA_SOUTHEAST"
     AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
+    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
+    AZURE_BRAZIL_SOUTH = "AZURE_BRAZIL_SOUTH"
+    AZURE_CANADA_CENTRAL = "AZURE_CANADA_CENTRAL"
+    AZURE_EUROPE_NORTH = "AZURE_EUROPE_NORTH"
+    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
+    AZURE_FRANCE_CENTRAL = "AZURE_FRANCE_CENTRAL"
     AZURE_GERMANY_WESTCENTRAL = "AZURE_GERMANY_WESTCENTRAL"
+    AZURE_INDIA_CENTRAL = "AZURE_INDIA_CENTRAL"
+    AZURE_INDIA_SOUTH = "AZURE_INDIA_SOUTH"
+    AZURE_JAPAN_EAST = "AZURE_JAPAN_EAST"
+    AZURE_JAPAN_WEST = "AZURE_JAPAN_WEST"
+    AZURE_KOREA_CENTRAL = "AZURE_KOREA_CENTRAL"
     AZURE_UAE_NORTH = "AZURE_UAE_NORTH"
+    AZURE_US_CENTRAL = "AZURE_US_CENTRAL"
+    AZURE_US_EAST = "AZURE_US_EAST"
+    AZURE_US_EAST2 = "AZURE_US_EAST2"
+    AZURE_US_WEST = "AZURE_US_WEST"
+    AZURE_US_WEST2 = "AZURE_US_WEST2"
+    AZURE_US_SOUTH_CENTRAL = "AZURE_US_SOUTH_CENTRAL"
     NORTH_AMERICA = "NORTH_AMERICA"
     SOUTH_AMERICA = "SOUTH_AMERICA"
     EUROPE = "EUROPE"
