@@ -13,13 +13,15 @@ class StreamsVideoCreateRequest(object):
                  asset_url=None,
                  title=None,
                  description=None,
-                 config_id=None):
-        # type: (string_types, string_types, string_types, string_types) -> None
+                 style_config_id=None,
+                 ad_config_id=None):
+        # type: (string_types, string_types, string_types, string_types, string_types) -> None
 
         self._asset_url = None
         self._title = None
         self._description = None
-        self._config_id = None
+        self._style_config_id = None
+        self._ad_config_id = None
         self.discriminator = None
 
         if asset_url is not None:
@@ -28,8 +30,10 @@ class StreamsVideoCreateRequest(object):
             self.title = title
         if description is not None:
             self.description = description
-        if config_id is not None:
-            self.config_id = config_id
+        if style_config_id is not None:
+            self.style_config_id = style_config_id
+        if ad_config_id is not None:
+            self.ad_config_id = ad_config_id
 
     @property
     def openapi_types(self):
@@ -37,7 +41,8 @@ class StreamsVideoCreateRequest(object):
             'asset_url': 'string_types',
             'title': 'string_types',
             'description': 'string_types',
-            'config_id': 'string_types'
+            'style_config_id': 'string_types',
+            'ad_config_id': 'string_types'
         }
 
         return types
@@ -48,7 +53,8 @@ class StreamsVideoCreateRequest(object):
             'asset_url': 'assetUrl',
             'title': 'title',
             'description': 'description',
-            'config_id': 'configId'
+            'style_config_id': 'styleConfigId',
+            'ad_config_id': 'adConfigId'
         }
         return attributes
 
@@ -140,33 +146,62 @@ class StreamsVideoCreateRequest(object):
         self._description = description
 
     @property
-    def config_id(self):
+    def style_config_id(self):
         # type: () -> string_types
-        """Gets the config_id of this StreamsVideoCreateRequest.
+        """Gets the style_config_id of this StreamsVideoCreateRequest.
 
-        Id of the stream config to use
+        Id of the style config to use
 
-        :return: The config_id of this StreamsVideoCreateRequest.
+        :return: The style_config_id of this StreamsVideoCreateRequest.
         :rtype: string_types
         """
-        return self._config_id
+        return self._style_config_id
 
-    @config_id.setter
-    def config_id(self, config_id):
+    @style_config_id.setter
+    def style_config_id(self, style_config_id):
         # type: (string_types) -> None
-        """Sets the config_id of this StreamsVideoCreateRequest.
+        """Sets the style_config_id of this StreamsVideoCreateRequest.
 
-        Id of the stream config to use
+        Id of the style config to use
 
-        :param config_id: The config_id of this StreamsVideoCreateRequest.
+        :param style_config_id: The style_config_id of this StreamsVideoCreateRequest.
         :type: string_types
         """
 
-        if config_id is not None:
-            if not isinstance(config_id, string_types):
-                raise TypeError("Invalid type for `config_id`, type has to be `string_types`")
+        if style_config_id is not None:
+            if not isinstance(style_config_id, string_types):
+                raise TypeError("Invalid type for `style_config_id`, type has to be `string_types`")
 
-        self._config_id = config_id
+        self._style_config_id = style_config_id
+
+    @property
+    def ad_config_id(self):
+        # type: () -> string_types
+        """Gets the ad_config_id of this StreamsVideoCreateRequest.
+
+        Id of the advertisement config to use
+
+        :return: The ad_config_id of this StreamsVideoCreateRequest.
+        :rtype: string_types
+        """
+        return self._ad_config_id
+
+    @ad_config_id.setter
+    def ad_config_id(self, ad_config_id):
+        # type: (string_types) -> None
+        """Sets the ad_config_id of this StreamsVideoCreateRequest.
+
+        Id of the advertisement config to use
+
+        :param ad_config_id: The ad_config_id of this StreamsVideoCreateRequest.
+        :type: string_types
+        """
+
+        if ad_config_id is not None:
+            if not isinstance(ad_config_id, string_types):
+                raise TypeError("Invalid type for `ad_config_id`, type has to be `string_types`")
+
+        self._ad_config_id = ad_config_id
 
     def to_dict(self):
         """Returns the model properties as a dict"""
