@@ -4,7 +4,10 @@ from enum import Enum
 from datetime import datetime
 from six import string_types, iteritems
 from bitmovin_api_sdk.common.poscheck import poscheck_model
-from bitmovin_api_sdk.models.streams_config_response import StreamsConfigResponse
+from bitmovin_api_sdk.models.streams_ad_config_response import StreamsAdConfigResponse
+from bitmovin_api_sdk.models.streams_content_protection_response import StreamsContentProtectionResponse
+from bitmovin_api_sdk.models.streams_style_config_response import StreamsStyleConfigResponse
+from bitmovin_api_sdk.models.streams_trimming_status import StreamsTrimmingStatus
 from bitmovin_api_sdk.models.streams_video_status import StreamsVideoStatus
 import pprint
 import six
@@ -19,9 +22,13 @@ class StreamsVideoResponse(object):
                  description=None,
                  created_at=None,
                  status=None,
-                 config=None,
-                 encoding_tasks=None):
-        # type: (string_types, string_types, string_types, string_types, datetime, StreamsVideoStatus, StreamsConfigResponse, list[StreamsVideoEncodingTask]) -> None
+                 style_config=None,
+                 encoding_tasks=None,
+                 poster_url=None,
+                 ad_config=None,
+                 content_protection=None,
+                 trimming=None):
+        # type: (string_types, string_types, string_types, string_types, datetime, StreamsVideoStatus, StreamsStyleConfigResponse, list[StreamsVideoEncodingTask], string_types, StreamsAdConfigResponse, StreamsContentProtectionResponse, StreamsTrimmingStatus) -> None
 
         self._id = None
         self._asset_url = None
@@ -29,8 +36,12 @@ class StreamsVideoResponse(object):
         self._description = None
         self._created_at = None
         self._status = None
-        self._config = None
+        self._style_config = None
         self._encoding_tasks = list()
+        self._poster_url = None
+        self._ad_config = None
+        self._content_protection = None
+        self._trimming = None
         self.discriminator = None
 
         if id_ is not None:
@@ -45,10 +56,18 @@ class StreamsVideoResponse(object):
             self.created_at = created_at
         if status is not None:
             self.status = status
-        if config is not None:
-            self.config = config
+        if style_config is not None:
+            self.style_config = style_config
         if encoding_tasks is not None:
             self.encoding_tasks = encoding_tasks
+        if poster_url is not None:
+            self.poster_url = poster_url
+        if ad_config is not None:
+            self.ad_config = ad_config
+        if content_protection is not None:
+            self.content_protection = content_protection
+        if trimming is not None:
+            self.trimming = trimming
 
     @property
     def openapi_types(self):
@@ -59,8 +78,12 @@ class StreamsVideoResponse(object):
             'description': 'string_types',
             'created_at': 'datetime',
             'status': 'StreamsVideoStatus',
-            'config': 'StreamsConfigResponse',
-            'encoding_tasks': 'list[StreamsVideoEncodingTask]'
+            'style_config': 'StreamsStyleConfigResponse',
+            'encoding_tasks': 'list[StreamsVideoEncodingTask]',
+            'poster_url': 'string_types',
+            'ad_config': 'StreamsAdConfigResponse',
+            'content_protection': 'StreamsContentProtectionResponse',
+            'trimming': 'StreamsTrimmingStatus'
         }
 
         return types
@@ -74,8 +97,12 @@ class StreamsVideoResponse(object):
             'description': 'description',
             'created_at': 'createdAt',
             'status': 'status',
-            'config': 'config',
-            'encoding_tasks': 'encodingTasks'
+            'style_config': 'styleConfig',
+            'encoding_tasks': 'encodingTasks',
+            'poster_url': 'posterUrl',
+            'ad_config': 'adConfig',
+            'content_protection': 'contentProtection',
+            'trimming': 'trimming'
         }
         return attributes
 
@@ -254,31 +281,31 @@ class StreamsVideoResponse(object):
         self._status = status
 
     @property
-    def config(self):
-        # type: () -> StreamsConfigResponse
-        """Gets the config of this StreamsVideoResponse.
+    def style_config(self):
+        # type: () -> StreamsStyleConfigResponse
+        """Gets the style_config of this StreamsVideoResponse.
 
 
-        :return: The config of this StreamsVideoResponse.
-        :rtype: StreamsConfigResponse
+        :return: The style_config of this StreamsVideoResponse.
+        :rtype: StreamsStyleConfigResponse
         """
-        return self._config
+        return self._style_config
 
-    @config.setter
-    def config(self, config):
-        # type: (StreamsConfigResponse) -> None
-        """Sets the config of this StreamsVideoResponse.
+    @style_config.setter
+    def style_config(self, style_config):
+        # type: (StreamsStyleConfigResponse) -> None
+        """Sets the style_config of this StreamsVideoResponse.
 
 
-        :param config: The config of this StreamsVideoResponse.
-        :type: StreamsConfigResponse
+        :param style_config: The style_config of this StreamsVideoResponse.
+        :type: StreamsStyleConfigResponse
         """
 
-        if config is not None:
-            if not isinstance(config, StreamsConfigResponse):
-                raise TypeError("Invalid type for `config`, type has to be `StreamsConfigResponse`")
+        if style_config is not None:
+            if not isinstance(style_config, StreamsStyleConfigResponse):
+                raise TypeError("Invalid type for `style_config`, type has to be `StreamsStyleConfigResponse`")
 
-        self._config = config
+        self._style_config = style_config
 
     @property
     def encoding_tasks(self):
@@ -309,6 +336,118 @@ class StreamsVideoResponse(object):
 
         self._encoding_tasks = encoding_tasks
 
+    @property
+    def poster_url(self):
+        # type: () -> string_types
+        """Gets the poster_url of this StreamsVideoResponse.
+
+        Poster URL
+
+        :return: The poster_url of this StreamsVideoResponse.
+        :rtype: string_types
+        """
+        return self._poster_url
+
+    @poster_url.setter
+    def poster_url(self, poster_url):
+        # type: (string_types) -> None
+        """Sets the poster_url of this StreamsVideoResponse.
+
+        Poster URL
+
+        :param poster_url: The poster_url of this StreamsVideoResponse.
+        :type: string_types
+        """
+
+        if poster_url is not None:
+            if not isinstance(poster_url, string_types):
+                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")
+
+        self._poster_url = poster_url
+
+    @property
+    def ad_config(self):
+        # type: () -> StreamsAdConfigResponse
+        """Gets the ad_config of this StreamsVideoResponse.
+
+
+        :return: The ad_config of this StreamsVideoResponse.
+        :rtype: StreamsAdConfigResponse
+        """
+        return self._ad_config
+
+    @ad_config.setter
+    def ad_config(self, ad_config):
+        # type: (StreamsAdConfigResponse) -> None
+        """Sets the ad_config of this StreamsVideoResponse.
+
+
+        :param ad_config: The ad_config of this StreamsVideoResponse.
+        :type: StreamsAdConfigResponse
+        """
+
+        if ad_config is not None:
+            if not isinstance(ad_config, StreamsAdConfigResponse):
+                raise TypeError("Invalid type for `ad_config`, type has to be `StreamsAdConfigResponse`")
+
+        self._ad_config = ad_config
+
+    @property
+    def content_protection(self):
+        # type: () -> StreamsContentProtectionResponse
+        """Gets the content_protection of this StreamsVideoResponse.
+
+
+        :return: The content_protection of this StreamsVideoResponse.
+        :rtype: StreamsContentProtectionResponse
+        """
+        return self._content_protection
+
+    @content_protection.setter
+    def content_protection(self, content_protection):
+        # type: (StreamsContentProtectionResponse) -> None
+        """Sets the content_protection of this StreamsVideoResponse.
+
+
+        :param content_protection: The content_protection of this StreamsVideoResponse.
+        :type: StreamsContentProtectionResponse
+        """
+
+        if content_protection is not None:
+            if not isinstance(content_protection, StreamsContentProtectionResponse):
+                raise TypeError("Invalid type for `content_protection`, type has to be `StreamsContentProtectionResponse`")
+
+        self._content_protection = content_protection
+
+    @property
+    def trimming(self):
+        # type: () -> StreamsTrimmingStatus
+        """Gets the trimming of this StreamsVideoResponse.
+
+        Stream trimming information
+
+        :return: The trimming of this StreamsVideoResponse.
+        :rtype: StreamsTrimmingStatus
+        """
+        return self._trimming
+
+    @trimming.setter
+    def trimming(self, trimming):
+        # type: (StreamsTrimmingStatus) -> None
+        """Sets the trimming of this StreamsVideoResponse.
+
+        Stream trimming information
+
+        :param trimming: The trimming of this StreamsVideoResponse.
+        :type: StreamsTrimmingStatus
+        """
+
+        if trimming is not None:
+            if not isinstance(trimming, StreamsTrimmingStatus):
+                raise TypeError("Invalid type for `trimming`, type has to be `StreamsTrimmingStatus`")
+
+        self._trimming = trimming
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
