@@ -14,13 +14,19 @@ class StreamsVideoUpdateRequest(object):
                  status=None,
                  title=None,
                  description=None,
-                 config_id=None):
-        # type: (StreamsVideoStatus, string_types, string_types, string_types) -> None
+                 style_config_id=None,
+                 poster_url=None,
+                 ad_config_id=None,
+                 content_protection_id=None):
+        # type: (StreamsVideoStatus, string_types, string_types, string_types, string_types, string_types, string_types) -> None
 
         self._status = None
         self._title = None
         self._description = None
-        self._config_id = None
+        self._style_config_id = None
+        self._poster_url = None
+        self._ad_config_id = None
+        self._content_protection_id = None
         self.discriminator = None
 
         if status is not None:
@@ -29,8 +35,14 @@ class StreamsVideoUpdateRequest(object):
             self.title = title
         if description is not None:
             self.description = description
-        if config_id is not None:
-            self.config_id = config_id
+        if style_config_id is not None:
+            self.style_config_id = style_config_id
+        if poster_url is not None:
+            self.poster_url = poster_url
+        if ad_config_id is not None:
+            self.ad_config_id = ad_config_id
+        if content_protection_id is not None:
+            self.content_protection_id = content_protection_id
 
     @property
     def openapi_types(self):
@@ -38,7 +50,10 @@ class StreamsVideoUpdateRequest(object):
             'status': 'StreamsVideoStatus',
             'title': 'string_types',
             'description': 'string_types',
-            'config_id': 'string_types'
+            'style_config_id': 'string_types',
+            'poster_url': 'string_types',
+            'ad_config_id': 'string_types',
+            'content_protection_id': 'string_types'
         }
 
         return types
@@ -49,7 +64,10 @@ class StreamsVideoUpdateRequest(object):
             'status': 'status',
             'title': 'title',
             'description': 'description',
-            'config_id': 'configId'
+            'style_config_id': 'styleConfigId',
+            'poster_url': 'posterUrl',
+            'ad_config_id': 'adConfigId',
+            'content_protection_id': 'contentProtectionId'
         }
         return attributes
 
@@ -141,33 +159,120 @@ class StreamsVideoUpdateRequest(object):
         self._description = description
 
     @property
-    def config_id(self):
+    def style_config_id(self):
         # type: () -> string_types
-        """Gets the config_id of this StreamsVideoUpdateRequest.
+        """Gets the style_config_id of this StreamsVideoUpdateRequest.
 
-        Id of the stream config to use
+        Id of the style config to use
 
-        :return: The config_id of this StreamsVideoUpdateRequest.
+        :return: The style_config_id of this StreamsVideoUpdateRequest.
         :rtype: string_types
         """
-        return self._config_id
+        return self._style_config_id
 
-    @config_id.setter
-    def config_id(self, config_id):
+    @style_config_id.setter
+    def style_config_id(self, style_config_id):
         # type: (string_types) -> None
-        """Sets the config_id of this StreamsVideoUpdateRequest.
+        """Sets the style_config_id of this StreamsVideoUpdateRequest.
 
-        Id of the stream config to use
+        Id of the style config to use
 
-        :param config_id: The config_id of this StreamsVideoUpdateRequest.
+        :param style_config_id: The style_config_id of this StreamsVideoUpdateRequest.
         :type: string_types
         """
 
-        if config_id is not None:
-            if not isinstance(config_id, string_types):
-                raise TypeError("Invalid type for `config_id`, type has to be `string_types`")
+        if style_config_id is not None:
+            if not isinstance(style_config_id, string_types):
+                raise TypeError("Invalid type for `style_config_id`, type has to be `string_types`")
 
-        self._config_id = config_id
+        self._style_config_id = style_config_id
+
+    @property
+    def poster_url(self):
+        # type: () -> string_types
+        """Gets the poster_url of this StreamsVideoUpdateRequest.
+
+        URL to hosted poster image
+
+        :return: The poster_url of this StreamsVideoUpdateRequest.
+        :rtype: string_types
+        """
+        return self._poster_url
+
+    @poster_url.setter
+    def poster_url(self, poster_url):
+        # type: (string_types) -> None
+        """Sets the poster_url of this StreamsVideoUpdateRequest.
+
+        URL to hosted poster image
+
+        :param poster_url: The poster_url of this StreamsVideoUpdateRequest.
+        :type: string_types
+        """
+
+        if poster_url is not None:
+            if not isinstance(poster_url, string_types):
+                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")
+
+        self._poster_url = poster_url
+
+    @property
+    def ad_config_id(self):
+        # type: () -> string_types
+        """Gets the ad_config_id of this StreamsVideoUpdateRequest.
+
+        Id of the advertisement config to use
+
+        :return: The ad_config_id of this StreamsVideoUpdateRequest.
+        :rtype: string_types
+        """
+        return self._ad_config_id
+
+    @ad_config_id.setter
+    def ad_config_id(self, ad_config_id):
+        # type: (string_types) -> None
+        """Sets the ad_config_id of this StreamsVideoUpdateRequest.
+
+        Id of the advertisement config to use
+
+        :param ad_config_id: The ad_config_id of this StreamsVideoUpdateRequest.
+        :type: string_types
+        """
+
+        if ad_config_id is not None:
+            if not isinstance(ad_config_id, string_types):
+                raise TypeError("Invalid type for `ad_config_id`, type has to be `string_types`")
+
+        self._ad_config_id = ad_config_id
+
+    @property
+    def content_protection_id(self):
+        # type: () -> string_types
+        """Gets the content_protection_id of this StreamsVideoUpdateRequest.
+
+        Id of the content protection config to use
+
+        :return: The content_protection_id of this StreamsVideoUpdateRequest.
+        :rtype: string_types
+        """
+        return self._content_protection_id
+
+    @content_protection_id.setter
+    def content_protection_id(self, content_protection_id):
+        # type: (string_types) -> None
+        """Sets the content_protection_id of this StreamsVideoUpdateRequest.
+
+        Id of the content protection config to use
+
+        :param content_protection_id: The content_protection_id of this StreamsVideoUpdateRequest.
+        :type: string_types
+        """
+
+        if content_protection_id is not None:
+            if not isinstance(content_protection_id, string_types):
+                raise TypeError("Invalid type for `content_protection_id`, type has to be `string_types`")
+
+        self._content_protection_id = content_protection_id
 
     def to_dict(self):
         """Returns the model properties as a dict"""
