@@ -318,7 +318,7 @@ class Task(BitmovinResponse):
         # type: () -> datetime
         """Gets the running_at of this Task.
 
-        Timestamp when the task status changed to to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the task status changed to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
 
         :return: The running_at of this Task.
         :rtype: datetime
@@ -330,7 +330,7 @@ class Task(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the running_at of this Task.
 
-        Timestamp when the task status changed to to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the task status changed to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
 
         :param running_at: The running_at of this Task.
         :type: datetime
@@ -347,7 +347,7 @@ class Task(BitmovinResponse):
         # type: () -> datetime
         """Gets the finished_at of this Task.
 
-        Timestamp when the task status changed to \"FINISHED\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the subtask status changed to a final state like 'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for tasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 
 
         :return: The finished_at of this Task.
         :rtype: datetime
@@ -359,7 +359,7 @@ class Task(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the finished_at of this Task.
 
-        Timestamp when the task status changed to \"FINISHED\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the subtask status changed to a final state like 'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for tasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 
 
         :param finished_at: The finished_at of this Task.
         :type: datetime
@@ -376,7 +376,7 @@ class Task(BitmovinResponse):
         # type: () -> datetime
         """Gets the error_at of this Task.
 
-        Timestamp when the task status changed to \"ERROR\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 
 
         :return: The error_at of this Task.
         :rtype: datetime
@@ -388,7 +388,7 @@ class Task(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the error_at of this Task.
 
-        Timestamp when the task status changed to \"ERROR\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ
+        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 
 
         :param error_at: The error_at of this Task.
         :type: datetime
