@@ -26,7 +26,7 @@ class ErrorApi(BaseApi):
         # type: (Webhook, dict) -> Webhook
         """Add &#39;Manifest Error&#39; Webhook (All Manifests)
 
-        :param webhook: Add a new webhook notification if a manifest creation failed with an error. A maximum number of 5 webhooks is allowed
+        :param webhook: The &#39;Manifest Error&#39; Webhook to be added.
         :type webhook: Webhook, required
         :return: Webhook Details
         :rtype: Webhook
