@@ -26,7 +26,7 @@ class FinishedApi(BaseApi):
         # type: (Webhook, dict) -> Webhook
         """Add &#39;Manifest Finished Successfully&#39; Webhook (All Manifests)
 
-        :param webhook: Add a new webhook notification if a manifest creation finished successfully. A maximum number of 5 webhooks is allowed
+        :param webhook: Add a new webhook notification that triggers if a manifest generation finished successfully. A maximum number of 5 webhooks is allowed
         :type webhook: Webhook, required
         :return: Webhook Details
         :rtype: Webhook
