@@ -1,4 +1,4 @@
 from bitmovin_api_sdk.streams.streams_api import StreamsApi
-from bitmovin_api_sdk.streams.configs.configs_api import ConfigsApi
+from bitmovin_api_sdk.streams.search.search_api import SearchApi
 from bitmovin_api_sdk.streams.video.video_api import VideoApi
 from bitmovin_api_sdk.streams.live.live_api import LiveApi
