@@ -4,7 +4,7 @@ from __future__ import absolute_import
 
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
-from bitmovin_api_sdk.streams.configs.configs_api import ConfigsApi
+from bitmovin_api_sdk.streams.search.search_api import SearchApi
 from bitmovin_api_sdk.streams.video.video_api import VideoApi
 from bitmovin_api_sdk.streams.live.live_api import LiveApi
 
@@ -21,7 +21,7 @@ class StreamsApi(BaseApi):
             logger=logger
         )
 
-        self.configs = ConfigsApi(
+        self.search = SearchApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
             base_url=base_url,
